@@ -22,6 +22,7 @@ from invoke import main
 from invoke.util import cd
 
 from _util import (
+    ROOT,
     expect,
     load,
     run,
@@ -31,9 +32,6 @@ from _util import (
 )
 
 
-ROOT = os.path.abspath(os.path.sep)
-
-
 pytestmark = pytest.mark.usefixtures("integration")
 
 
@@ -158,6 +156,38 @@ class Program_:
             assert "myapp [--core-opts]" in stdout
             assert "/usr/local/bin" not in stdout
 
+    class called_as:
+        # NOTE: these tests are meh due to Program's lifecycle design
+        # (attributes get modified during run(), such as things based on
+        # observed argv). It's not great, but, whatever.
+        @trap
+        def is_the_whole_deal_when_just_a_name(self):
+            p = Program()
+            p.run("whatever --help", exit=False)
+            assert p.called_as == "whatever"
+
+        @trap
+        def is_basename_when_given_a_path(self):
+            p = Program()
+            p.run("/usr/local/bin/whatever --help", exit=False)
+            assert p.called_as == "whatever"
+
+    class binary_names:
+        # NOTE: this is currently only used for completion stuff, so we use
+        # that to test. TODO: maybe make this more unit-y...
+        def defaults_to_argv_when_None(self):
+            stdout, _ = run("foo --print-completion-script zsh", invoke=False)
+            assert " foo" in stdout
+
+        def can_be_given_directly(self):
+            program = Program(binary_names=["foo", "bar"])
+            stdout, _ = run(
+                "foo --print-completion-script zsh",
+                invoke=False,
+                program=program,
+            )
+            assert " foo bar" in stdout
+
     class print_version:
         def displays_name_and_version(self):
             expect(
@@ -425,31 +455,33 @@ Usage: inv[oke] [--core-opts] task1 [--task1-opts] ... taskN [--taskN-opts]
 
 Core options:
 
-  --complete                        Print tab-completion candidates for given
-                                    parse remainder.
-  --hide=STRING                     Set default value of run()'s 'hide' kwarg.
-  --no-dedupe                       Disable task deduplication.
-  --prompt-for-sudo-password        Prompt user at start of session for the
-                                    sudo.password config value.
-  --write-pyc                       Enable creation of .pyc files.
-  -c STRING, --collection=STRING    Specify collection name to load.
-  -d, --debug                       Enable debug output.
-  -D INT, --list-depth=INT          When listing tasks, only show the first INT
-                                    levels.
-  -e, --echo                        Echo executed commands before running.
-  -f STRING, --config=STRING        Runtime configuration file to use.
-  -F STRING, --list-format=STRING   Change the display format used when listing
-                                    tasks. Should be one of: flat (default),
-                                    nested, json.
-  -h [STRING], --help[=STRING]      Show core or per-task help and exit.
-  -l [STRING], --list[=STRING]      List available tasks, optionally limited to
-                                    a namespace.
-  -p, --pty                         Use a pty when executing shell commands.
-  -r STRING, --search-root=STRING   Change root directory used for finding task
-                                    modules.
-  -V, --version                     Show version and exit.
-  -w, --warn-only                   Warn, instead of failing, when shell
-                                    commands fail.
+  --complete                         Print tab-completion candidates for given
+                                     parse remainder.
+  --hide=STRING                      Set default value of run()'s 'hide' kwarg.
+  --no-dedupe                        Disable task deduplication.
+  --print-completion-script=STRING   Print the tab-completion script for your
+                                     preferred shell (bash|zsh|fish).
+  --prompt-for-sudo-password         Prompt user at start of session for the
+                                     sudo.password config value.
+  --write-pyc                        Enable creation of .pyc files.
+  -c STRING, --collection=STRING     Specify collection name to load.
+  -d, --debug                        Enable debug output.
+  -D INT, --list-depth=INT           When listing tasks, only show the first
+                                     INT levels.
+  -e, --echo                         Echo executed commands before running.
+  -f STRING, --config=STRING         Runtime configuration file to use.
+  -F STRING, --list-format=STRING    Change the display format used when
+                                     listing tasks. Should be one of: flat
+                                     (default), nested, json.
+  -h [STRING], --help[=STRING]       Show core or per-task help and exit.
+  -l [STRING], --list[=STRING]       List available tasks, optionally limited
+                                     to a namespace.
+  -p, --pty                          Use a pty when executing shell commands.
+  -r STRING, --search-root=STRING    Change root directory used for finding
+                                     task modules.
+  -V, --version                      Show version and exit.
+  -w, --warn-only                    Warn, instead of failing, when shell
+                                     commands fail.
 
 """.lstrip()
                 for flag in ["-h", "--help"]:
